# `autopaths` version 1.0.1

`autopaths` is a python package for dealing with file paths and automation.

It contains several submodules that are useful when building pipelines. See below for examples and documentation.

# FilePath object

Here is an example usage of this object:

    from autopaths.file_path import FilePath
    f = FilePath("input/raw/reads_56.fastq")

Once you have created a FilePath, many useful methods are available. Here are a few:


To see the complete list, look at the source code.

# DirectoryPath object

Similar to a file path object.

# AutoPaths object
